@@ -1,52 +1,47 @@
 import logging
 
-import aprslib
 from ax253 import Frame
 import kiss
+from oslo_config import cfg
 
-from aprsd import messaging
+from aprsd import conf  # noqa
+from aprsd.packets import core
 from aprsd.utils import trace
 
 
+CONF = cfg.CONF
 LOG = logging.getLogger("APRSD")
 
 
 class KISS3Client:
-    def __init__(self, config):
-        self.config = config
+    def __init__(self):
         self.setup()
 
     def setup(self):
         # we can be TCP kiss or Serial kiss
-        if "serial" in self.config["kiss"] and self.config["kiss"]["serial"].get(
-            "enabled",
-            False,
-        ):
+        if CONF.kiss_serial.enabled:
             LOG.debug(
                 "KISS({}) Serial connection to {}".format(
                     kiss.__version__,
-                    self.config["kiss"]["serial"]["device"],
+                    CONF.kiss_serial.device,
                 ),
             )
             self.kiss = kiss.SerialKISS(
-                port=self.config["kiss"]["serial"]["device"],
-                speed=self.config["kiss"]["serial"].get("baudrate", 9600),
+                port=CONF.kiss_serial.device,
+                speed=CONF.kiss_serial.baudrate,
                 strip_df_start=True,
             )
-        elif "tcp" in self.config["kiss"] and self.config["kiss"]["tcp"].get(
-            "enabled",
-            False,
-        ):
+        elif CONF.kiss_tcp.enabled:
             LOG.debug(
                 "KISS({}) TCP Connection to {}:{}".format(
                     kiss.__version__,
-                    self.config["kiss"]["tcp"]["host"],
-                    self.config["kiss"]["tcp"]["port"],
+                    CONF.kiss_tcp.host,
+                    CONF.kiss_tcp.port,
                 ),
             )
             self.kiss = kiss.TCPKISS(
-                host=self.config["kiss"]["tcp"]["host"],
-                port=int(self.config["kiss"]["tcp"]["port"]),
+                host=CONF.kiss_tcp.host,
+                port=CONF.kiss_tcp.port,
                 strip_df_start=True,
             )
 
@@ -68,14 +63,16 @@ class KISS3Client:
         pass
 
     def parse_frame(self, frame_bytes):
-        frame = Frame.from_bytes(frame_bytes)
-        # Now parse it with aprslib
-        packet = aprslib.parse(str(frame))
-        kwargs = {
-            "frame": str(frame),
-            "packet": packet,
-        }
-        self._parse_callback(**kwargs)
+        try:
+            frame = Frame.from_bytes(frame_bytes)
+            # Now parse it with aprslib
+            kwargs = {
+                "frame": frame,
+            }
+            self._parse_callback(**kwargs)
+        except Exception as ex:
+            LOG.error("Failed to parse bytes received from KISS interface.")
+            LOG.exception(ex)
 
     def consumer(self, callback, blocking=False, immortal=False, raw=False):
         LOG.debug("Start blocking KISS consumer")
@@ -83,7 +80,7 @@ class KISS3Client:
         self.kiss.read(callback=self.parse_frame, min_frames=None)
         LOG.debug("END blocking KISS consumer")
 
-    def send(self, msg):
+    def send(self, packet):
         """Send an APRS Message object."""
 
         # payload = (':%-9s:%s' % (
@@ -93,26 +90,26 @@ class KISS3Client:
         # payload = str(msg).encode('US-ASCII')
         payload = None
         path = ["WIDE1-1", "WIDE2-1"]
-        if isinstance(msg, messaging.AckMessage):
-            msg_payload = f"ack{msg.id}"
-        elif isinstance(msg, messaging.RawMessage):
-            payload = msg.message.encode("US-ASCII")
+        if isinstance(packet, core.AckPacket):
+            msg_payload = f"ack{packet.msgNo}"
+        elif isinstance(packet, core.Packet):
+            payload = packet.raw.encode("US-ASCII")
             path = ["WIDE2-1"]
         else:
-            msg_payload = f"{msg.message}{{{str(msg.id)}"
+            msg_payload = f"{packet.raw}{{{str(packet.msgNo)}"
 
         if not payload:
             payload = (
                 ":{:<9}:{}".format(
-                    msg.tocall,
+                    packet.to_call,
                     msg_payload,
                 )
             ).encode("US-ASCII")
 
         LOG.debug(f"Send '{payload}' TO KISS")
         frame = Frame.ui(
-            destination=msg.tocall,
-            source=msg.fromcall,
+            destination=packet.to_call,
+            source=packet.from_call,
             path=path,
             info=payload,
         )
