@@ -2,19 +2,22 @@ import logging
 import re
 import time
 
+from oslo_config import cfg
 import pytz
 
-from aprsd import plugin, plugin_utils
+from aprsd import packets, plugin, plugin_utils
 from aprsd.utils import fuzzy, trace
 
 
+CONF = cfg.CONF
 LOG = logging.getLogger("APRSD")
 
 
 class TimePlugin(plugin.APRSDRegexCommandPluginBase):
     """Time command."""
 
-    command_regex = "^[tT]"
+    # Look for t or t<space> or T<space> or time
+    command_regex = r"^([t]|[t]\s|time)"
     command_name = "time"
     short_description = "What is the current local time."
 
@@ -42,7 +45,7 @@ class TimePlugin(plugin.APRSDRegexCommandPluginBase):
         return reply
 
     @trace.trace
-    def process(self, packet):
+    def process(self, packet: packets.Packet):
         LOG.info("TIME COMMAND")
         # So we can mock this in unit tests
         localzone = self._get_local_tz()
@@ -52,7 +55,7 @@ class TimePlugin(plugin.APRSDRegexCommandPluginBase):
 class TimeOWMPlugin(TimePlugin, plugin.APRSFIKEYMixin):
     """OpenWeatherMap based timezone fetching."""
 
-    command_regex = "^[tT]"
+    command_regex = r"^([t]|[t]\s|time)"
     command_name = "time"
     short_description = "Current time of GPS beacon's timezone. Uses OpenWeatherMap"
 
@@ -60,9 +63,9 @@ class TimeOWMPlugin(TimePlugin, plugin.APRSFIKEYMixin):
         self.ensure_aprs_fi_key()
 
     @trace.trace
-    def process(self, packet):
-        fromcall = packet.get("from")
-        message = packet.get("message_text", None)
+    def process(self, packet: packets.MessagePacket):
+        fromcall = packet.from_call
+        message = packet.message_text
         # ack = packet.get("msgNo", "0")
 
         # optional second argument is a callsign to search
@@ -74,7 +77,7 @@ class TimeOWMPlugin(TimePlugin, plugin.APRSFIKEYMixin):
             # if no second argument, search for calling station
             searchcall = fromcall
 
-        api_key = self.config["services"]["aprs.fi"]["apiKey"]
+        api_key = CONF.aprs_fi.apiKey
         try:
             aprs_data = plugin_utils.get_aprs_fi(api_key, searchcall)
         except Exception as ex:
