@@ -7,7 +7,4 @@ from .keep_alive import KeepAliveThread  # noqa: F401
 from .rx import APRSDRXThread  # noqa: F401
 
 
-rx_msg_queue = queue.Queue(maxsize=20)
-msg_queues = {
-    "rx": rx_msg_queue,
-}
+packet_queue = queue.Queue(maxsize=20)
